SmartDebounceStream<T> extension

on

Methods

debounceTime(Duration duration) Stream<T>

Available on Stream<T>, provided by the SmartDebounceStream extension

Emits events from this stream only after the source has been silent for duration.
throttleTime(Duration duration, {bool leading = true, bool trailing = true}) Stream<T>

Available on Stream<T>, provided by the SmartDebounceStream extension

Emits at most one value per duration, honoring the leading and trailing edge configuration.